# coding=utf8
""" CLI

Used for shim to run the program from the command line
"""

from __future__ import print_function

__author__		= "Chris Nasr"
__copyright__	= "Ouroboros Coding Inc."
__version__		= "1.0.0"
__email__		= "chris@ouroboroscoding.com"
__created__		= "2022-02-24"

# Python imports
from argparse import ArgumentParser
import json
import sys

# Local imports
from . import main

def cli():
	"""CLI

	Called from the command line to load a config file and run pylivedev

	Returns:
		uint
	"""

	# Setup the argument parser
	oArgParser = ArgumentParser(description='Python Live Development')
	oArgParser.add_argument('-c', '--config', nargs=1, default='.pylivedev', help='The configuration file to load')

	# Parse the arguments
	mArgs = oArgParser.parse_args()

	# Attempt to load the config file
	try:
		with open(mArgs.config, 'r') as oF:

			# If it's opened, decode the JSON inside
			oConf = json.load(oF)

			# Pass the JSON to the module and close with whatever status it returns
			sys.exit(
				main(oConf) == False and 1 or 0
			)

	except IOError as e:
		print(e)

# Only run if main
if __name__ == '__main__':
	cli()



from setuptools import setup

setup(
	name='pylivedev',
	version='0.1.0',
	url='https://github.com/ouroboroscoding/pylivedev',
	description='PyLiveDev is used to keep track of files associated with your script so it can be re-started if any file is updated.',
	keywords=['python','live', 'development'],
	author='Chris Nasr - OuroborosCoding',
	author_email='chris@ouroboroscoding.com',
	license='Apache-2.0',
	packages=['pylivedev'],
	install_requires=[
		'watchdog>=2.1.2'
	],
	entry_points={
		'console_scripts': ['pylivedev=pylivedev.__main__:cli']
	},
	zip_safe=True
)
